@@ -108,28 +108,30 @@ class FrescoApp(RouteCollection):
         for traversal in routecollection.get_routes(path, method):
 
             route = traversal.route
-            if route.predicate and not route.predicate(request):
-                continue
-
-            for k, v in traversal.kwargs.items():
-                if isinstance(v, RouteKwarg):
-                    v = v(request)
-                traversal.kwargs[k] = v
-
-            environ['wsgiorg.routing_args'] = (traversal.args,
-                                               traversal.kwargs)
-            context.view_self = getattr(route.original_view, '__self__', None)
-
-            if self.logger:
-                self.logger.info("matched route: %s %r => %r", request.method,
-                                 path, route.original_view)
-
-            context.route_collections_traversed = \
-                        traversal.collections_traversed
-            self.route_matched.send(self, route=route, view=route.view,
-                                    request=request)
-
             try:
+                if route.predicate and not route.predicate(request):
+                    continue
+
+                for k, v in traversal.kwargs.items():
+                    if isinstance(v, RouteKwarg):
+                        v = v(request)
+                    traversal.kwargs[k] = v
+
+                environ['wsgiorg.routing_args'] = (traversal.args,
+                                                traversal.kwargs)
+                context.view_self = getattr(route.original_view, '__self__',
+                                            None)
+
+                if self.logger:
+                    self.logger.info("matched route: %s %r => %r",
+                                     request.method,
+                                     path, route.original_view)
+
+                context.route_collections_traversed = \
+                            traversal.collections_traversed
+                self.route_matched.send(self, route=route, view=route.view,
+                                        request=request)
+
                 response = route.view(*traversal.args, **traversal.kwargs)
             except ResponseException as e:
                 if e.is_final:
