@@ -276,7 +276,7 @@ class Request(object):
             ...     c.request.parsed_url
             ('https', 'example.com', '/animals/view', '', 'name=lion', '')
 
-        Components are returned as a unicode strings
+        Components are returned as unicode strings
         """
         env = self.environ.get
         script_name = quote(self.script_name.encode(self.charset))
@@ -472,11 +472,16 @@ class Request(object):
             >>> request.make_url(path='../../../plum')
             'http://example.com/plum'
 
+        :rtype: str
         """
         url = []
         parsed_url = self.parsed_url
 
         if path is not None:
+            if not isinstance(path, bytes):
+                path = path.encode('utf-8')
+            path = quote(path)
+
             if path[0] != '/':
                 path = posixpath.join(
                         posixpath.dirname(parsed_url[2]), path)
@@ -488,18 +493,17 @@ class Request(object):
             if PATH_INFO is None:
                 PATH_INFO = self.path_info
             path = SCRIPT_NAME + PATH_INFO
+            if not isinstance(path, bytes):
+                path = path.encode('utf-8')
+            path = quote(path)
+
         else:
             path = parsed_url[2]
 
-        if not isinstance(path, bytes):
-            path = path.encode('utf-8')
-        path = quote(path)
-
         if query is not None:
             if not isinstance(query, string_types):
                 query = make_query(query, **kwargs)
             elif isinstance(query, bytes):
-                query = query.decode('iso-8859-1')
                 if kwargs:
                     if query:
                         query += ';'
