@@ -169,14 +169,14 @@ def encoder(stream, charset):
 
     Synopsis::
 
-        >>> list(encoder([u'Price \u00a3200'], 'latin1'))
-        ['Price \xa3200']
+        >>> list(encoder(['Price \u00a3200'], 'latin1'))
+        [b'Price \xa3200']
     """
     if charset is None:
         charset = 'UTF-8'
 
     for chunk in stream:
-        if isinstance(chunk, unicode):
+        if not isinstance(chunk, bytes):
             yield chunk.encode(charset)
         else:
             yield chunk
@@ -557,7 +557,7 @@ class Response(object):
 
         Synopsis::
 
-            >>> def view(request):
+            >>> def view():
             ...     return Response.not_found()
             ...
         """
@@ -580,7 +580,7 @@ class Response(object):
 
         Synopsis::
 
-            >>> def view(request):
+            >>> def view():
             ...     return Response.forbidden()
             ...
         """
@@ -602,7 +602,7 @@ class Response(object):
 
         Synopsis::
 
-            >>> def view(request):
+            >>> def view():
             ...     return Response.bad_request()
             ...
 
@@ -625,7 +625,7 @@ class Response(object):
 
         Synopsis::
 
-            >>> def view(request):
+            >>> def view():
             ...     return Response.length_required()
             ...
 
@@ -672,7 +672,7 @@ class Response(object):
         """\
         Return an HTTP method not allowed response (405)::
 
-            >>> def view(request):
+            >>> def view():
             ...     if request.method == 'POST':
             ...         return Response.method_not_allowed(('POST', ))
             ...
@@ -700,7 +700,7 @@ class Response(object):
 
         Synopsis::
 
-            >>> def view(request):
+            >>> def view():
             ...     return Response.internal_server_error()
             ...
 
@@ -729,7 +729,7 @@ class Response(object):
 
         Synopsis:
 
-            >>> def view(request):
+            >>> def view():
             ...   return Response.redirect("/new-location")
             ...
         """
@@ -832,7 +832,7 @@ def make_headers(header_list, header_dict):
         [('Content-Type', 'text/html'), ('X-Foo', 'a1'), ('X-Foo', 'b2')]
 
     """
-    headers = header_list + header_dict.items()
+    headers = header_list + list(header_dict.items())
     headers = [(make_header_name(key), val)
                for key, val in headers if val is not None]
 
@@ -847,6 +847,21 @@ def make_headers(header_list, header_dict):
     return newheaders
 
 
+def dump_response(r, line_break='\r\n'):
+    """\
+    Return a string representation of the given response, as for a HTTP
+    response.
+    """
+    output = []
+    output.append(r.status)
+    output.append(line_break)
+    output.extend('{}: {}{}'.format(k, v, line_break)
+                  for k, v in sorted(r.headers))
+    output.append(line_break)
+    output.extend(r.content)
+    return ''.join(output)
+
+
 def make_status(status):
     """
     Return a status line from the given status, which may be a simple integer.
