@@ -101,15 +101,30 @@ class TestPathEncoding(object):
 
 class TestMakeURL(object):
 
-    def test_returns_request_url(self):
+    def test_it_returns_request_url(self):
         with context(SCRIPT_NAME='/script', PATH_INFO='/pathinfo') as c:
             assert_equal(c.request.make_url(),
                          'http://localhost/script/pathinfo')
 
+    def test_it_doesnt_double_quote_request_url(self):
+        with context(SCRIPT_NAME='/script name', PATH_INFO='/path info') as c:
+            assert_equal(c.request.make_url(),
+                         'http://localhost/script%20name/path%20info')
+
+    def test_it_doesnt_double_quote_supplied_path_info(self):
+        with context() as c:
+            assert_equal(c.request.make_url(PATH_INFO='/x y'),
+                         'http://localhost/x%20y')
+
     def test_can_replace_path(self):
         with context(SCRIPT_NAME='/script', PATH_INFO='/pathinfo') as c:
-            assert_equal(c.request.make_url(path='/foo'),
-                         'http://localhost/foo')
+            assert_equal(c.request.make_url(path='/foo bar'),
+                         'http://localhost/foo%20bar')
+
+    def test_it_joins_path(self):
+        with context(SCRIPT_NAME='/script name', PATH_INFO='/path info/') as c:
+            assert_equal(c.request.make_url(path='a/b c'),
+                         'http://localhost/script%20name/path%20info/a/b%20c')
 
     def test_query_not_included_by_default(self):
         with context(QUERY_STRING='query=foo') as c:
@@ -144,6 +159,11 @@ class TestMakeURL(object):
             assert_equal(c.request.make_url(query={'e': e}),
                          'http://localhost/?e=%C3%A9')
 
+    def test_it_quotes_paths(self):
+        with context() as c:
+            assert_equal(c.request.make_url(path='/a b'),
+                         'http://localhost/a%20b')
+
 
 class TestResolveURL(object):
 
@@ -235,98 +255,3 @@ class TestFiles(object):
         assert request.files['uploaded_file'].headers['content-type'] \
                 == 'text/plain'
         assert request.files['uploaded_file'].filename == self.filename
-
-#def test_parsing_cookie_header():
-#    @to_wsgi
-#    def app():
-#        return Response([
-#            str(cookie) + '\n' for name, cookie in request.cookies.allitems()
-#        ])
-#
-#    assert_equal(
-#        TestApp(app).get(HTTP_COOKIE='$Version=1; NAME=a; $Path="/"; $Domain=".some.domain.org"; NAME=b;').body,
-#        "NAME=a;Domain=.some.domain.org;Path=/;Version=1\n"
-#        "NAME=b;Version=1\n",
-#    )
-#
-#
-#def test_method_not_allowed_dispatcher():
-#    dispatcher = dispatcher_app()
-#
-#    @dispatcher.match('/blah', 'DELETE', 'PUT')
-#    def app():
-#        return Response.method_not_allowed(request)
-#
-#    response = TestApp(dispatcher).get('/blah')
-#    assert 'not allowed' in response.body.lower()
-#    assert_equal(response.status, "405 Method Not Allowed")
-#    assert_equal(response.get_header('Allow'), 'PUT,DELETE')
-#
-
-#def test_request_path():
-#
-#    request = Request(make_environ(SCRIPT_NAME='/foo', PATH_INFO='/bar', HTTP_HOST='localhost:80'))
-#    assert_equal(request.request_path, "/foo/bar")
-#
-#    request = Request(make_environ(SCRIPT_NAME='/foo/bar', PATH_INFO='', HTTP_HOST='localhost:80'))
-#    assert_equal(request.request_path, "/foo/bar")
-#
-#    request = Request(make_environ(SCRIPT_NAME='/', PATH_INFO='foo/bar', HTTP_HOST='localhost:80'))
-#    assert_equal(request.request_path, "/foo/bar")
-#
-#def test_form():
-#
-#    request = Request(make_environ(QUERY_STRING='foo=bar'))
-#    assert_equal(request.get('foo'), 'bar')
-#    assert_equal(request['foo'], 'bar')
-#    assert_equal(request.get('fuz'), None)
-#
-#    request = Request(make_environ(QUERY_STRING='foo=bar&foo=baz'))
-#    assert_equal(request.get('foo'), 'bar')
-#    assert_equal(request['foo'], 'bar')
-#    assert_equal(request.getlist('foo'), ['bar', u'baz'])
-#
-#def test_remote_addr():
-#    request = Request(make_environ(REMOTE_ADDR="1.2.3.4", HTTP_X_FORWARDED_FOR="4.3.2.1"))
-#    assert request.remote_addr == "1.2.3.4"
-#
-#
-#def test_encoding():
-#
-#    # Test UTF-8 decoding works (this should be the default)
-#    request = Request(make_environ(QUERY_STRING=make_query(foo='\xa0'.encode('utf8'))))
-#    assert_equal(request.get('foo'), '\xa0')
-#
-#    # Force a different encoding
-#    request = Request(make_environ(QUERY_STRING=make_query(foo='\xa0'.encode('utf7'))))
-#    request.charset = 'utf-7'
-#    assert_equal(request.get('foo'), '\xa0')
-#
-#    # Force an incorrect encoding
-#    request = Request(make_environ(QUERY_STRING=make_query(foo='\xa0'.encode('utf8'))))
-#    request.charset = 'utf-7'
-#    assert_raises(RequestParseError, request.get, 'foo')
-#
-#def test_form_getters():
-#
-#    alpha = '\u03b1' # Greek alpha
-#    beta = '\u03b2' # Greek beta
-#    gamma = '\u03b3' # Greek gamma
-#
-#    request = Request(make_environ(
-#        QUERY_STRING='foo=%s;foo=%s;bar=%s' % (
-#            quote(alpha.encode('utf-8')),
-#            quote(beta.encode('utf-8')),
-#            quote(gamma.encode('utf-8'))
-#        )
-#    ))
-#    assert request.get('foo') == request.form.get('foo') == alpha
-#    assert request.getlist('foo') == request.form.getlist('foo') == [alpha, beta]
-#
-#    assert request.get('cheese') == request.form.get('cheese') == None
-#    assert request.getlist('cheese') == request.form.getlist('cheese') == []
-#
-#    assert request.get('bar') == request.form.get('bar') == gamma
-#    assert request.getlist('bar') == request.form.getlist('bar') == [gamma]
-#
-#
