@@ -183,12 +183,12 @@ class TestRouteKwargs(object):
             app.view()
             view.assert_called_with(x='d')
 
-    def test_requestarg_raises_exception(self):
+    def test_requestarg_returns_badrequest(self):
         view = Mock()
         app = FrescoApp()
         app.route('/', GET, view, x=FormArg())
         with app.requestcontext('/'):
-            assert_raises(BadRequest, app.view)
+            assert 'Bad Request' in app.view().status
 
 
 class TestRouteNames(object):
