@@ -20,7 +20,7 @@ except ImportError:
 from shutil import copyfileobj
 
 import fresco
-from fresco.compat import PY3
+from fresco.compat import PY3, string_types
 from fresco.exceptions import RequestParseError
 from fresco.util.io import ExpandableOutput, SizeLimitedInput, PutbackInput, \
                            DelimitedInput
@@ -331,8 +331,8 @@ class FileUpload(object):
         :param fileob: a file-like object open for writing, or the path to the
                        file to be written
         """
-        if isinstance(fileob, basestring):
-            with open(fileob, 'w') as f:
+        if isinstance(fileob, string_types):
+            with open(fileob, 'wb') as f:
                 return self.save(f)
 
         self.file.seek(0)
